# Security Policy

## Supported Versions

Podman-HPC is currently under early development, and all security updates
will be made to the latest release.  

| Version       | Supported          |
| ------------- | ------------------ |
| latest        | :white_check_mark: |
| anything else | :x:                |

## Reporting a Vulnerability

If you think you've identified a security issue in Podman-HPC. please DO NOT 
report the issue in a public forum.  Instead, gather as many details as possible
and include them in a ticket to the NERSC Help Portal at https://nersc.servicenowservices.com/,
or send an email to security@nersc.gov.

For any issues with Podman itself, please follow the security policy
detailed at https://github.com/containers/podman

